==> nocc-1.9.1.tbz: www/nocc/lang/hu.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: hu.php 2376 2011-01-22 19:46:26Z gerundt $
 */
/** Hungarian (Magyar)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Dani
 * @author Enbéká
 * @author Glanthor Reviol
 * @author Hajdu Zoltán <wirhock@wirhock.com>
 * @author Leiric
 */

$lang_locale = 'hu_HU.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y.%m.%d';
$default_time_format = '%H:%M';
$err_user_empty = 'Az azonosítót meg kell adni';
$err_passwd_empty = 'A jelszót meg kell adni';
$alt_delete = 'Kijelölt üzenetek törlése';
$alt_delete_one = 'Üzenet törlése';
$alt_new_msg = 'Új üzenetek';
$alt_reply = 'Válaszol';
$alt_reply_all = 'Mindre válaszol';
$alt_forward = 'Továbbítás';
$alt_next = 'Következő';
$alt_prev = 'Előző';
$title_next_page = 'Következő oldal';
$title_prev_page = 'Előző oldal';
$title_next_msg = 'Következõ üzenet';
$title_prev_msg = 'Előző üzenet';
$html_theme_label = 'Téma:';
$html_welcome = 'Üdvözli a %1$s';
$html_login = 'Bejelentkezés';
$html_user_label = 'Felhasználó:';
$html_passwd_label = 'Jelszó:';
$html_submit = 'Bejelentkezés';
$html_help = 'Segítség';
$html_server_label = 'Szerver:';
$html_wrong = 'Az azonosító vagy jelszó nem megfelelõ';
$html_retry = 'Újra';
$html_remember = 'Beállítások megjegyzése';
$html_lang_label = 'Nyelv:';
$html_msgperpage_label = 'Oldalankénti üzenetek száma:';
$html_preferences = 'Beállítások';
$html_full_name_label = 'Teljes név:';
$html_email_address_label = 'E-mail cím:';
$html_bccself = 'Bcc self';
$html_hide_addresses = 'Címek elrejtése';
$html_outlook_quoting = 'Outlook-stílusú idézés';
$html_reply_to = 'Válasz';
$html_use_signature = 'Aláírás használata';
$html_signature = 'Aláírás';
$html_signature_label = 'Aláírás:';
$html_reply_leadin_label = 'Válasz bevezetője:';
$html_prefs_updated = 'A beállításokat mentettük';
$html_manage_folders_link = 'IMAP-mappák kezelése';
$html_manage_filters_link = 'Emailszűrők kezelése';
$html_use_graphical_smilies = 'Grafikus hangulatjelek használata';
$html_sent_folder_label = 'A küldött üzenetek másolása egy kijelölt mappába:';
$html_trash_folder_label = 'A törölt üzenetek áthelyezése egy kijelölt mappába:';
$html_colored_quotes = 'Színezett idézetek';
$html_display_struct = 'Rendezett szöveg megjelenítése';
$html_send_html_mail = 'Levél küldése HTML formátumban';
$html_folders = 'Mappák';
$html_folders_create_failed = 'Nem sikerült létrehozni a mappát!';
$html_folders_sub_failed = 'Nem sikerült feliratkozni a mappára!';
$html_folders_unsub_failed = 'Nem sikerült leiratkozni a mappáról!';
$html_folders_rename_failed = 'A mappát nem sikerült átnevezni!';
$html_folders_updated = 'A mappák frissítve lettek';
$html_folder_subscribe = 'Feliratkozás';
$html_folder_rename = 'Átnevezés';
$html_folder_create = 'Új mappa létrehozása';
$html_folder_remove = 'Leiratkozás';
$html_folder_delete = 'Törlés';
$html_folder_to = 'ide';
$html_filter_remove = 'Törlés';
$html_filter_body = 'Üzenet szövege';
$html_filter_subject = 'Üzenet tárgya';
$html_filter_to = 'Címzett mező';
$html_filter_cc = 'Másolat mező';
$html_filter_from = 'Küldő mező';
$html_filter_change_tip = 'A szűrő megváltoztatásához egyszerűen írd felül.';
$html_reapply_filters = 'Összes szűrő újraalkalmazása';
$html_filter_contains = 'tartalmazza';
$html_filter_name = 'Szűrő neve';
$html_filter_action = 'Szűrés';
$html_filter_moveto = 'Mozgatás ide';
$html_select_one = '-- Válassz egyet --';
$html_and = 'és';
$html_new_msg_in = 'Új üzenetek itt';
$html_or = 'vagy';
$html_move = 'Áthelyezés';
$html_copy = 'Másolás';
$html_messages_to = 'a kiválasztott üzeneteket ide';
$html_gotopage = 'Ugrás oldalhoz';
$html_gotofolder = 'Ugrás mappához';
$html_other_folders = 'Mappa lista';
$html_page = 'Lap';
$html_of = 'innen';
$html_view_header = 'Fejléc mutatása';
$html_remove_header = 'Fejléc rejtése';
$html_inbox = 'Érkezett';
$html_new_msg = 'ír';
$html_reply = 'Válaszol';
$html_reply_short = 'Re:';
$html_reply_all = 'Mindre válaszol';
$html_forward = 'Továbbküld';
$html_forward_short = 'Fwd:';
$html_forward_info = 'A továbbítandó üzenetet ehhez az üzenethez csatolt állományként lesz elküldve.';
$html_delete = 'Törlés';
$html_new = 'Új';
$html_mark = 'Törlés';
$html_att_label = 'Csatolt fájl:';
$html_atts_label = 'Csatolmányok:';
$html_unknown = '[ismeretlen]';
$html_attach = 'Csatol';
$html_attach_forget = 'Csatolni kell a fájlt üzenetküldés elõtt !';
$html_attach_delete = 'Csatolmány törlése';
$html_attach_none = 'Ki kell választanod egy csatolandó állományt!';
$html_sort_by = 'Rendezés';
$html_sort = 'Rendezés';
$html_from = 'Feladó';
$html_from_label = 'Feladó:';
$html_subject = 'Cím';
$html_subject_label = 'Tárgy:';
$html_date = 'Dátum';
$html_date_label = 'Dátum:';
$html_sent_label = 'Elküldve:';
$html_wrote = 'írta';
$html_size = 'Méret';
$html_totalsize = 'Teljes méret';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bájt';
$html_filename = 'Fájlnév';
$html_to = 'Címzett';
$html_to_label = 'Címzett:';
$html_cc = 'Másolat';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Titkos másolat:';
$html_nosubject = 'Nincs tárgy';
$html_send = 'Mehet';
$html_cancel = 'Mégse';
$html_no_mail = 'Nincs üzenet.';
$html_logout = 'Kilép';
$html_msg = 'Üzenet';
$html_msgs = 'Üzenetek';
$html_configuration = 'Ez a kiszolgáló nincs jól beállítva!';
$html_priority = 'Prioritás';
$html_priority_label = 'Prioritás:';
$html_lowest = 'Legalacsonyabb';
$html_low = 'Alacsony';
$html_normal = 'Normál';
$html_high = 'Magas';
$html_highest = 'Legmagasabb';
$html_flagged = 'Megjelölve';
$html_spam = 'Spam';
$html_spam_warning = 'Ez az üzenet levélszemétnek lett minősítve.';
$html_receipt = 'Visszajelzés kérése';
$html_select = 'Kiválaszt';
$html_select_all = 'Kijelölés megfordítása';
$html_select_contacts = 'Kapcsolatok kiválasztása';
$html_loading_image = 'Kép betöltése';
$html_send_confirmed = 'Az e-mailedet átvettük kézbesítésre';
$html_no_sendaction = 'Nincs kijelölt teendő. Próbáld meg bekapcsolni a JavaScriptet.';
$html_error_occurred = 'Hiba történt';
$html_prefs_file_error = 'Nem tudom megnyitni a beállításokat írásra.';
$html_wrap = 'Kimenő üzenetek sortörése ennyi karakter után:';
$html_wrap_none = 'Nincs sortörés';
$html_usenet_separator = 'Usenet elválasztó ("-- \n") az aláírás előtt';
$html_mark_as = 'Megjelölés mint';
$html_read = 'olvasott';
$html_unread = 'olvasatlan';
$html_encoding_label = 'Karaktertábla:';
$html_add = 'Hozzáadás';
$html_contacts = '%1$s Kapcsolat';
$html_modify = 'Módosít';
$html_back = 'Vissza';
$html_contact_add = 'Új kapcsolat';
$html_contact_mod = 'Kapcsolat módosítása';
$html_contact_first = 'Keresztnév';
$html_contact_last = 'Családnév';
$html_contact_nick = 'Becenév';
$html_contact_mail = 'E-mail cím';
$html_contact_list = 'Kapcsolatlista (%1$s)';
$html_contact_del = 'a kapcsolat listából';
$html_contact_count = '%1$d kapcsolat';
$html_contact_err1 = 'A kapcsolatok maximális száma "%1$d"';
$html_contact_err2 = 'Nem vehetsz föl új kapcsolatot';
$html_contact_err3 = 'Nincs hozzáférési jogosultságod a kapcsolatlistához';
$html_contact_none = 'Nincsenek kapcsolatok';
$html_del_msg = 'Törlöd a kiválasztott üzeneteket?';
$html_down_mail = 'Letöltés';
$original_msg = '-- Eredeti üzenet --';
$to_empty = 'A \'Címzett\' mezõt ki kell tölteni !';
$html_images_warning = 'A biztonságod érdekében a távoli képek nem jelennek meg.';
$html_images_display = 'Képek megjelenítése';
$html_smtp_error_no_conn = 'Az SMTP kapcsolat nem hozható létre';
$html_smtp_error_unexpected = 'Váratlan SMTP válasz:';
$lang_could_not_connect = 'A kiszolgálóhoz nem lehet csatlakozni';
$lang_invalid_msg_num = 'Rossz üzenet szám';
$html_file_upload_attack = 'Lehetséges állomány-feltöltési támadás';
$html_invalid_email_address = 'Érvénytelen e-mail cím';
$html_invalid_msg_per_page = 'Érvénytelen oldalankénti üzenet szám';
$html_invalid_wrap_msg = 'Érvénytlen sortörési szélesség';
$html_seperate_msg_win = 'Üzenetek külön ablakban';
$html_err_file_contacts = 'A kapcsolatlista nem nyitható meg írásra';
$html_session_file_error = 'A fájl nem nyitható meg írásra';
$html_login_not_allowed = 'Ez a belépési azonosító nem csatlakozhat';
$lang_err_send_delay = 'Várnod kell két e-mail küldése között (%1$d másodperc)';
$html_search = 'Keresés';

==> nocc-1.9.3.tbz: www/nocc/lang/hu.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: hu.php 2523 2011-12-03 11:41:12Z siebrand $
 */
/** Hungarian (Magyar)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Dani
 * @author Dj
 * @author Enbéká
 * @author Glanthor Reviol
 * @author Hajdu Zoltán <wirhock@wirhock.com>
 * @author Leiric
 */

$lang_locale = 'hu_HU.UTF-8';
$default_date_format = '%Y-%m-%d';
$no_locale_date_format = '%Y.%m.%d';
$default_time_format = '%H:%M';
$err_user_empty = 'Az azonosítót meg kell adni';
$err_passwd_empty = 'A jelszót meg kell adni';
$alt_delete = 'Kijelölt üzenetek törlése';
$alt_delete_one = 'Üzenet törlése';
$alt_new_msg = 'Új üzenetek';
$alt_reply = 'Válaszol';
$alt_reply_all = 'Mindre válaszol';
$alt_forward = 'Továbbítás';
$alt_next = 'Következő';
$alt_prev = 'Előző';
$title_next_page = 'Következő oldal';
$title_prev_page = 'Előző oldal';
$title_next_msg = 'Következő üzenet';
$title_prev_msg = 'Előző üzenet';
$html_theme_label = 'Téma:';
$html_welcome = 'Üdvözli a %1$s';
$html_login = 'Bejelentkezés';
$html_user_label = 'Felhasználó:';
$html_passwd_label = 'Jelszó:';
$html_submit = 'Bejelentkezés';
$html_help = 'Segítség';
$html_server_label = 'Szerver:';
$html_wrong = 'Az azonosító vagy jelszó nem megfelelő';
$html_retry = 'Újra';
$html_remember = 'Beállítások megjegyzése';
$html_lang_label = 'Nyelv:';
$html_msgperpage_label = 'Oldalankénti üzenetek száma:';
$html_preferences = 'Beállítások';
$html_full_name_label = 'Teljes név:';
$html_email_address_label = 'E-mail cím:';
$html_bccself = 'Titkos másolat magamnak';
$html_hide_addresses = 'Címek elrejtése';
$html_outlook_quoting = 'Outlook-stílusú idézés';
$html_reply_to = 'Válasz';
$html_reply_to_label = 'Válasz:';
$html_use_signature = 'Aláírás használata';
$html_signature = 'Aláírás';
$html_signature_label = 'Aláírás:';
$html_reply_leadin_label = 'Válasz bevezetője:';
$html_prefs_updated = 'A beállításokat mentettük';
$html_manage_folders_link = 'IMAP-mappák kezelése';
$html_manage_filters_link = 'Emailszűrők kezelése';
$html_use_graphical_smilies = 'Grafikus hangulatjelek használata';
$html_sent_folder_label = 'A küldött üzenetek másolása egy kijelölt mappába:';
$html_trash_folder_label = 'A törölt üzenetek áthelyezése egy kijelölt mappába:';
$html_colored_quotes = 'Színezett idézetek';
$html_display_struct = 'Rendezett szöveg megjelenítése';
$html_send_html_mail = 'Levél küldése HTML formátumban';
$html_folders = 'Mappák';
$html_folders_create_failed = 'Nem sikerült létrehozni a mappát!';
$html_folders_sub_failed = 'Nem sikerült feliratkozni a mappára!';
$html_folders_unsub_failed = 'Nem sikerült leiratkozni a mappáról!';
$html_folders_rename_failed = 'A mappát nem sikerült átnevezni!';
$html_folders_updated = 'A mappák frissítve lettek';
$html_folder_subscribe = 'Feliratkozás';
$html_folder_rename = 'Átnevezés';
$html_folder_create = 'Új mappa létrehozása';
$html_folder_remove = 'Leiratkozás';
$html_folder_delete = 'Törlés';
$html_folder_to = 'ide';
$html_filter_remove = 'Törlés';
$html_filter_body = 'Üzenet szövege';
$html_filter_subject = 'Üzenet tárgya';
$html_filter_to = 'Címzett mező';
$html_filter_cc = 'Másolat mező';
$html_filter_from = 'Küldő mező';
$html_filter_change_tip = 'A szűrő megváltoztatásához egyszerűen írd felül.';
$html_reapply_filters = 'Összes szűrő újraalkalmazása';
$html_filter_contains = 'tartalmazza';
$html_filter_name = 'Szűrő neve';
$html_filter_action = 'Szűrés';
$html_filter_moveto = 'Mozgatás ide';
$html_select_one = '-- Válassz egyet --';
$html_and = 'és';
$html_new_msg_in = 'Új üzenetek itt';
$html_or = 'vagy';
$html_move = 'Áthelyezés';
$html_copy = 'Másolás';
$html_messages_to = 'a kiválasztott üzeneteket ide';
$html_gotopage = 'Ugrás oldalhoz';
$html_gotofolder = 'Ugrás mappához';
$html_other_folders = 'Mappa lista';
$html_page = 'Lap';
$html_of = 'innen';
$html_view_header = 'Fejléc mutatása';
$html_remove_header = 'Fejléc rejtése';
$html_inbox = 'Érkezett';
$html_new_msg = 'ír';
$html_reply = 'Válaszol';
$html_reply_short = 'Re:';
$html_reply_all = 'Mindre válaszol';
$html_forward = 'Továbbküld';
$html_forward_short = 'Fwd:';
$html_forward_info = 'A továbbítandó üzenetet ehhez az üzenethez csatolt állományként lesz elküldve.';
$html_delete = 'Törlés';
$html_new = 'Új';
$html_mark = 'Törlés';
$html_att_label = 'Csatolt fájl:';
$html_atts_label = 'Csatolmányok:';
$html_unknown = '[ismeretlen]';
$html_part_x = '%s. rész';
$html_attach = 'Csatol';
$html_attach_forget = 'Csatolni kell a fájlt üzenetküldés előtt!';
$html_attach_delete = 'Csatolmány törlése';
$html_attach_none = 'Ki kell választanod egy csatolandó állományt!';
$html_sort_by = 'Rendezés';
$html_sort = 'Rendezés';
$html_from = 'Feladó';
$html_from_label = 'Feladó:';
$html_subject = 'Cím';
$html_subject_label = 'Tárgy:';
$html_date = 'Dátum';
$html_date_label = 'Dátum:';
$html_sent_label = 'Elküldve:';
$html_wrote = 'írta';
$html_size = 'Méret';
$html_totalsize = 'Teljes méret';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bájt';
$html_filename = 'Fájlnév';
$html_to = 'Címzett';
$html_to_label = 'Címzett:';
$html_cc = 'Másolat';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Titkos másolat:';
$html_nosubject = 'Nincs tárgy';
$html_send = 'Mehet';
$html_cancel = 'Mégse';
$html_no_mail = 'Nincs üzenet.';
$html_logout = 'Kilép';
$html_msg = 'Üzenet';
$html_msgs = 'Üzenetek';
$html_configuration = 'Ez a kiszolgáló nincs jól beállítva!';
$html_priority = 'Prioritás';
$html_priority_label = 'Prioritás:';
$html_lowest = 'Legalacsonyabb';
$html_low = 'Alacsony';
$html_normal = 'Normál';
$html_high = 'Magas';
$html_highest = 'Legmagasabb';
$html_flagged = 'Megjelölve';
$html_spam = 'Spam';
$html_spam_warning = 'Ez az üzenet levélszemétnek lett minősítve.';
$html_receipt = 'Visszajelzés kérése';
$html_select = 'Kiválaszt';
$html_select_all = 'Kijelölés megfordítása';
$html_select_contacts = 'Kapcsolatok kiválasztása';
$html_loading_image = 'Kép betöltése';
$html_send_confirmed = 'Az e-mailedet átvettük kézbesítésre';
$html_no_sendaction = 'Nincs kijelölt teendő. Próbáld meg bekapcsolni a JavaScriptet.';
$html_error_occurred = 'Hiba történt';
$html_prefs_file_error = 'Nem tudom megnyitni a beállításokat írásra.';
$html_wrap = 'Kimenő üzenetek sortörése ennyi karakter után:';
$html_wrap_none = 'Nincs sortörés';
$html_usenet_separator = 'Usenet elválasztó ("-- \n") az aláírás előtt';
$html_mark_as = 'Megjelölés mint';
$html_read = 'olvasott';
$html_unread = 'olvasatlan';
$html_encoding_label = 'Karaktertábla:';
$html_add = 'Hozzáadás';
$html_contacts = '%1$s Kapcsolat';
$html_modify = 'Módosít';
$html_back = 'Vissza';
$html_contact_add = 'Új kapcsolat';
$html_contact_mod = 'Kapcsolat módosítása';
$html_contact_first = 'Keresztnév';
$html_contact_last = 'Családnév';
$html_contact_nick = 'Becenév';
$html_contact_mail = 'E-mail cím';
$html_contact_list = 'Kapcsolatlista (%1$s)';
$html_contact_del = 'a kapcsolat listából';
$html_contact_count = '%1$d kapcsolat';
$html_contact_err1 = 'A kapcsolatok maximális száma "%1$d"';
$html_contact_err2 = 'Nem vehetsz föl új kapcsolatot';
$html_contact_err3 = 'Nincs hozzáférési jogosultságod a kapcsolatlistához';
$html_contact_none = 'Nincsenek kapcsolatok';
$html_del_msg = 'Törlöd a kiválasztott üzeneteket?';
$html_down_mail = 'Letöltés';
$original_msg = '-- Eredeti üzenet --';
$to_empty = 'A \'Címzett\' mezőt ki kell tölteni!';
$html_images_warning = 'A biztonságod érdekében a távoli képek nem jelennek meg.';
$html_images_display = 'Képek megjelenítése';
$html_smtp_error_no_conn = 'Az SMTP kapcsolat nem hozható létre';
$html_smtp_error_unexpected = 'Váratlan SMTP válasz:';
$lang_could_not_connect = 'A kiszolgálóhoz nem lehet csatlakozni';
$lang_invalid_msg_num = 'Rossz üzenet szám';
$html_file_upload_attack = 'Lehetséges állomány-feltöltési támadás';
$html_invalid_email_address = 'Érvénytelen e-mail cím';
$html_invalid_msg_per_page = 'Érvénytelen oldalankénti üzenet szám';
$html_invalid_wrap_msg = 'Érvénytlen sortörési szélesség';
$html_seperate_msg_win = 'Üzenetek külön ablakban';
$html_err_file_contacts = 'A kapcsolatlista nem nyitható meg írásra';
$html_session_file_error = 'A fájl nem nyitható meg írásra';
$html_login_not_allowed = 'Ez a belépési azonosító nem csatlakozhat';
$lang_err_send_delay = 'Várnod kell két e-mail küldése között (%1$d másodperc)';
$html_search = 'Keresés';
